==> kea-devel-docs-1.5.0-2.0-any.pkg.tar.zst: usr/share/doc/kea/devel/d2/d26/option__definition_8h.js <==
var option__definition_8h =
[
    [ "DuplicateOptionDefinition", "df/d70/classisc_1_1dhcp_1_1DuplicateOptionDefinition.html", "df/d70/classisc_1_1dhcp_1_1DuplicateOptionDefinition" ],
    [ "InvalidOptionValue", "d8/df1/classisc_1_1dhcp_1_1InvalidOptionValue.html", "d8/df1/classisc_1_1dhcp_1_1InvalidOptionValue" ],
    [ "MalformedOptionDefinition", "d9/da7/classisc_1_1dhcp_1_1MalformedOptionDefinition.html", "d9/da7/classisc_1_1dhcp_1_1MalformedOptionDefinition" ],
    [ "OptionDefinition", "df/d6a/classisc_1_1dhcp_1_1OptionDefinition.html", "df/d6a/classisc_1_1dhcp_1_1OptionDefinition" ],
    [ "OptionInt", "d4/d82/classisc_1_1dhcp_1_1OptionInt.html", "d4/d82/classisc_1_1dhcp_1_1OptionInt" ],
    [ "OptionIntArray", "db/d73/classisc_1_1dhcp_1_1OptionIntArray.html", "db/d73/classisc_1_1dhcp_1_1OptionIntArray" ],
    [ "OptionDefContainer", "d2/d26/option__definition_8h.html#ab4af5c0cf9cebf835ff29304e9c09125", null ],
    [ "OptionDefContainerNameIndex", "d2/d26/option__definition_8h.html#aca1efa0eefdf342ea08a73b2c1b5de66", null ],
    [ "OptionDefContainerNameRange", "d2/d26/option__definition_8h.html#a91ec7ac83e1dbaf6e2d09ff2216346aa", null ],
    [ "OptionDefContainerPtr", "d2/d26/option__definition_8h.html#afd6d2c70235c1e6611c1a013988b17dc", null ],
    [ "OptionDefContainers", "d2/d26/option__definition_8h.html#abee7857f2614979ff5b84b5726c702c5", null ],
    [ "OptionDefContainerTypeIndex", "d2/d26/option__definition_8h.html#af0adca3d7f67b8b0bff9e5f626e1f285", null ],
    [ "OptionDefContainerTypeRange", "d2/d26/option__definition_8h.html#acccccd92e3990ff27603ad698b74ecf2", null ],
    [ "OptionDefinitionPtr", "d2/d26/option__definition_8h.html#a7f7298f8ea5b1e9876baf0fbeabe5b21", null ],
    [ "OptionDefSpaceContainer", "d2/d26/option__definition_8h.html#a0c1e7c39119cd5ded410423463cad102", null ],
    [ "VendorOptionDefContainers", "d2/d26/option__definition_8h.html#a7e0c735717d3e5b355a66dc2d929eeda", null ]
];

==> kea-devel-docs-1.5.0-2.1-any.pkg.tar.zst: usr/share/doc/kea/devel/d2/d26/option__definition_8h.js <==
var option__definition_8h =
[
    [ "isc::dhcp::DuplicateOptionDefinition", "df/d70/classisc_1_1dhcp_1_1DuplicateOptionDefinition.html", "df/d70/classisc_1_1dhcp_1_1DuplicateOptionDefinition" ],
    [ "isc::dhcp::InvalidOptionValue", "d8/df1/classisc_1_1dhcp_1_1InvalidOptionValue.html", "d8/df1/classisc_1_1dhcp_1_1InvalidOptionValue" ],
    [ "isc::dhcp::MalformedOptionDefinition", "d9/da7/classisc_1_1dhcp_1_1MalformedOptionDefinition.html", "d9/da7/classisc_1_1dhcp_1_1MalformedOptionDefinition" ],
    [ "isc::dhcp::OptionDefinition", "df/d6a/classisc_1_1dhcp_1_1OptionDefinition.html", "df/d6a/classisc_1_1dhcp_1_1OptionDefinition" ],
    [ "OptionDefContainer", "d2/d26/option__definition_8h.html#ab4af5c0cf9cebf835ff29304e9c09125", null ],
    [ "OptionDefContainerNameIndex", "d2/d26/option__definition_8h.html#aca1efa0eefdf342ea08a73b2c1b5de66", null ],
    [ "OptionDefContainerNameRange", "d2/d26/option__definition_8h.html#a91ec7ac83e1dbaf6e2d09ff2216346aa", null ],
    [ "OptionDefContainerPtr", "d2/d26/option__definition_8h.html#afd6d2c70235c1e6611c1a013988b17dc", null ],
    [ "OptionDefContainers", "d2/d26/option__definition_8h.html#abee7857f2614979ff5b84b5726c702c5", null ],
    [ "OptionDefContainerTypeIndex", "d2/d26/option__definition_8h.html#af0adca3d7f67b8b0bff9e5f626e1f285", null ],
    [ "OptionDefContainerTypeRange", "d2/d26/option__definition_8h.html#acccccd92e3990ff27603ad698b74ecf2", null ],
    [ "OptionDefinitionPtr", "d2/d26/option__definition_8h.html#a7f7298f8ea5b1e9876baf0fbeabe5b21", null ],
    [ "OptionDefSpaceContainer", "d2/d26/option__definition_8h.html#a0c1e7c39119cd5ded410423463cad102", null ],
    [ "VendorOptionDefContainers", "d2/d26/option__definition_8h.html#a7e0c735717d3e5b355a66dc2d929eeda", null ]
];
